==> ah-form-builder-sample-0.6.19.tgz: package/es/components/toolbar/field-forms/Video.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/toolbar/field-forms/Video.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, updateField as _updateField, deleteNewField as _deleteNewField } from "../../../actions/formActions";
import { connect } from "react-redux";
import FileUpload from "../../../utils/file-upload";
import TextInput from "../../../utils/inputs/TextInput";
import { Scrollbars } from 'react-custom-scrollbars';
import FormHelperText from '@material-ui/core/FormHelperText';
import Checkbox from '../../../utils/checkboxs/Checkbox';
import { getHeight } from '../../../utils/helpers';

var Video = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Video, _React$Component);

  function Video(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          subType = _this$state.subType,
          uuid = _this$state.uuid,
          type = _this$state.type,
          url = _this$state.url,
          href = _this$state.href,
          autoPlay = _this$state.autoPlay,
          visibility = _this$state.visibility,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          subType: subType,
          url: url,
          href: href,
          autoPlay: autoPlay,
          visibility: visibility
        }
      };
      ValidateField(newField).then(function () {
        _this.props.updateField(newField);

        _this.props.disableFieldEdit();
      })["catch"](function (err) {
        _this.setState({
          errors: err
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderFields", function () {
      return /*#__PURE__*/React.createElement("div", {
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 57,
          columnNumber: 7
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 58,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(TextInput, {
        label: "Url",
        value: _this.state.url,
        handleChange: function handleChange(e) {
          return _this.handleDataChange(e.target.value, 'url');
        },
        autoFocus: true,
        error: _this.state.errors.url,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 59,
          columnNumber: 11
        }
      })), /*#__PURE__*/React.createElement("div", {
        className: "separator mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 61,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("span", {
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 61,
          columnNumber: 41
        }
      }, "OR")), /*#__PURE__*/React.createElement("div", {
        className: "mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 62,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(FileUpload, {
        label: "File Upload",
        fileUploadUrl: _this.props.fileUploadUrl,
        url: _this.state.url,
        updateUrl: function updateUrl(url) {
          return _this.handleDataChange(url, 'url');
        },
        variant: "videos",
        uploadable: true,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 63,
          columnNumber: 11
        }
      }), _this.state.errors.upload ? /*#__PURE__*/React.createElement(FormHelperText, {
        error: true,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 65,
          columnNumber: 13
        }
      }, _this.state.errors.upload) : ""), /*#__PURE__*/React.createElement("div", {
        className: "mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 68,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(TextInput, {
        label: "Link on video",
        value: _this.state.href,
        handleChange: function handleChange(e) {
          return _this.handleDataChange(e.target.value, 'href');
        },
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 69,
          columnNumber: 11
        }
      })), /*#__PURE__*/React.createElement(Checkbox, {
        checked: _this.state.autoPlay,
        handleChange: function handleChange(val) {
          return _this.handleDataChange(val, 'autoPlay');
        },
        label: "Auto Play video",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 71,
          columnNumber: 9
        }
      }));
    });

    _this.state = _extends({
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName
    }, props.data.config);
    return _this;
  }

  var _proto = Video.prototype;

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 78,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, false)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 79,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "p-3 my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 80,
        columnNumber: 11
      }
    }, this.renderFields(), /*#__PURE__*/React.createElement("div", {
      className: "width-full text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 82,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      color: "primary",
      className: "mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 83,
        columnNumber: 15
      }
    }, "Cancel"), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      color: "primary",
      disableElevation: true,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 86,
        columnNumber: 15
      }
    }, "Save")))));
  };

  return Video;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    fileUploadUrl: state.form.fileUploadUrl
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Video);

==> ah-form-builder-sample-0.6.82.tgz: package/es/components/toolbar/field-forms/Video.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/toolbar/field-forms/Video.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, updateField as _updateField, deleteNewField as _deleteNewField } from "../../../actions/formActions";
import { connect } from "react-redux";
import FileUpload from "../../../utils/file-upload";
import TextInput from "../../../utils/inputs/TextInput";
import { Scrollbars } from 'react-custom-scrollbars';
import FormHelperText from '@material-ui/core/FormHelperText';
import Checkbox from '../../../utils/checkboxs/Checkbox';
import { getHeight } from '../../../utils/helpers';
var urlLabel = {
  en: 'Url',
  ar: 'عنوان url'
};
var orLabel = {
  en: 'OR',
  ar: 'أو'
};
var uploadLabel = {
  en: 'File Upload',
  ar: 'تحميل الملف'
};
var linkLabel = {
  en: 'Link on Video',
  ar: 'رابط على الفيديو'
};
var autoplayLabel = {
  en: 'Auto Play Video',
  ar: 'تشغيل تلقائي للفيديو'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};

var Video = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Video, _React$Component);

  function Video(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          subType = _this$state.subType,
          uuid = _this$state.uuid,
          type = _this$state.type,
          url = _this$state.url,
          href = _this$state.href,
          autoPlay = _this$state.autoPlay,
          visibility = _this$state.visibility,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          subType: subType,
          url: url,
          href: href,
          autoPlay: autoPlay,
          visibility: visibility
        }
      };
      ValidateField(newField).then(function () {
        _this.props.updateField(newField);

        _this.props.disableFieldEdit();
      })["catch"](function (err) {
        _this.setState({
          errors: err
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderFields", function () {
      return /*#__PURE__*/React.createElement("div", {
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 100,
          columnNumber: 7
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 101,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(TextInput, {
        label: urlLabel[_this.props.currentLang],
        value: _this.state.url,
        handleChange: function handleChange(e) {
          return _this.handleDataChange(e.target.value, 'url');
        },
        autoFocus: true,
        error: _this.state.errors.url,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 102,
          columnNumber: 11
        }
      })), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-separator ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 104,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("span", {
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 104,
          columnNumber: 51
        }
      }, orLabel[_this.props.currentLang])), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 105,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(FileUpload, {
        label: uploadLabel[_this.props.currentLang],
        fileUploadUrl: _this.props.fileUploadUrl,
        url: _this.state.url,
        updateUrl: function updateUrl(url) {
          return _this.handleDataChange(url, 'url');
        },
        variant: "videos",
        uploadable: true,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 106,
          columnNumber: 11
        }
      }), _this.state.errors.upload ? /*#__PURE__*/React.createElement(FormHelperText, {
        error: true,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 108,
          columnNumber: 13
        }
      }, _this.state.errors.upload) : ""), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 111,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(TextInput, {
        label: linkLabel[_this.props.currentLang],
        value: _this.state.href,
        handleChange: function handleChange(e) {
          return _this.handleDataChange(e.target.value, 'href');
        },
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 112,
          columnNumber: 11
        }
      })), /*#__PURE__*/React.createElement(Checkbox, {
        checked: _this.state.autoPlay,
        handleChange: function handleChange(val) {
          return _this.handleDataChange(val, 'autoPlay');
        },
        label: autoplayLabel[_this.props.currentLang],
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 114,
          columnNumber: 9
        }
      }));
    });

    _this.state = _extends({
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName
    }, props.data.config);
    return _this;
  }

  var _proto = Video.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 121,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, false)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 122,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 123,
        columnNumber: 11
      }
    }, this.renderFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 125,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      color: "primary",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 126,
        columnNumber: 15
      }
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      color: "primary",
      disableElevation: true,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 129,
        columnNumber: 15
      }
    }, saveLabel[this.props.currentLang])))));
  };

  return Video;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    fileUploadUrl: state.form.fileUploadUrl,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Video);
